@@ -42,13 +42,12 @@ import shutil
 import subprocess
 import tarfile
 from argparse import Action
+from configparser import ConfigParser, DuplicateSectionError, NoOptionError, NoSectionError
 from datetime import date
 from glob import glob
 from json import dumps
 from tempfile import NamedTemporaryFile, mkdtemp
-
-from six.moves.configparser import ConfigParser, DuplicateSectionError, NoOptionError, NoSectionError
-from six.moves.urllib_parse import urljoin
+from urllib.parse import urljoin
 
 from univention.appcenter.actions import StoreAppAction, UniventionAppAction, get_action
 from univention.appcenter.app import App, AppFileAttribute, CaseSensitiveConfigParser, LooseVersion
@@ -155,7 +154,7 @@ class LocalAppcenterAction(UniventionAppAction):
         if src == dst:
             try:
                 os.chmod(result_file, 0o644)
-            except EnvironmentError as exc:
+            except OSError as exc:
                 self.warn(exc)
                 return False
             else:
@@ -163,7 +162,7 @@ class LocalAppcenterAction(UniventionAppAction):
         try:
             shutil.copy2(src, dst)
             os.chmod(result_file, 0o644)
-        except EnvironmentError as exc:
+        except OSError as exc:
             self.warn(exc)
             return False
         else:
@@ -746,7 +745,7 @@ class DevSet(UniventionAppAction):
             self.log('Removing %s' % attr)
             try:
                 os.unlink(app.get_cache_file(attr))
-            except EnvironmentError:
+            except OSError:
                 pass
 
     def process(self, app, attribute, section, attr, value, parser):
