@@ -37,15 +37,9 @@
 
 import re
 from argparse import Action
+from configparser import NoOptionError, NoSectionError
 from fnmatch import translate
-
-
-try:
-    from shlex import quote
-except ImportError:
-    from pipes import quote
-
-from six.moves.configparser import NoOptionError, NoSectionError
+from shlex import quote
 
 from univention.appcenter.actions import StoreAppAction, UniventionAppAction
 from univention.appcenter.app import CaseSensitiveConfigParser
@@ -148,10 +142,7 @@ class Get(UniventionAppAction):
     def raw_value(cls, app, section, option):
         config_parser = CaseSensitiveConfigParser()
         with open(app.get_ini_file()) as f:
-            if hasattr(config_parser, 'read_file'):
-                config_parser.read_file(f)
-            else:
-                config_parser.readfp(f)
+            config_parser.read_file(f)
         try:
             return config_parser.get(section, option)
         except (NoSectionError, NoOptionError):
@@ -160,10 +151,7 @@ class Get(UniventionAppAction):
     def get_values(self, app, keys, warn=True):
         config_parser = CaseSensitiveConfigParser()
         with open(app.get_ini_file()) as f:
-            if hasattr(config_parser, 'read_file'):
-                config_parser.read_file(f)
-            else:
-                config_parser.readfp(f)
+            config_parser.read_file(f)
         for section, key in keys:
             search_section = section or 'Application'
             found = False
