@@ -39,7 +39,6 @@ import os
 from ipaddress import AddressValueError, IPv4Address, IPv4Network
 
 import MySQLdb as mysql
-import six
 
 from univention.appcenter.log import LogCatcher, get_base_logger
 from univention.appcenter.packages import (
@@ -114,7 +113,7 @@ class DatabaseConnector(object):
         try:
             with open(db_password_file) as f:
                 return f.read().rstrip('\n')
-        except EnvironmentError:
+        except OSError:
             return None
 
     def get_db_password_file(self):
@@ -180,7 +179,7 @@ class DatabaseConnector(object):
             with open(db_password_file, 'w') as f:
                 os.chmod(f.name, 0o600)
                 f.write(password)
-        except EnvironmentError as exc:
+        except OSError as exc:
             raise DatabaseCreationFailed(str(exc))
         else:
             database_logger.info('Password for %s database in %s' % (self.app.id, db_password_file))
@@ -189,7 +188,7 @@ class DatabaseConnector(object):
         try:
             with open(self.get_db_password_file()) as f:
                 return f.read().rstrip('\n')
-        except (EnvironmentError, TypeError):
+        except (OSError, TypeError):
             return None
 
     def db_exists(self):
@@ -335,8 +334,8 @@ class MySQL(DatabaseConnector):
 
     def escape(self, value):
         print(repr(value))
-        print(repr(six.text_type(value)))
-        return self.get_root_connection().escape(six.text_type(value))
+        print(repr(str(value)))
+        return self.get_root_connection().escape(str(value))
 
     def create_db_and_user(self, password):
         self.execute('CREATE DATABASE IF NOT EXISTS `%s`' % self.get_db_name())
