@@ -38,11 +38,9 @@
 
 import codecs
 import re
+from configparser import DuplicateSectionError, NoOptionError, NoSectionError, ParsingError, RawConfigParser
 from copy import deepcopy
 
-from six import with_metaclass
-from six.moves.configparser import DuplicateSectionError, NoOptionError, NoSectionError, ParsingError, RawConfigParser
-
 from univention.appcenter.log import get_base_logger
 from univention.appcenter.meta import UniventionMetaClass, UniventionMetaInfo
 from univention.appcenter.utils import get_locale
@@ -74,13 +72,10 @@ def read_ini_file(filename, parser_class=RawConfigParser):
     parser = parser_class()
     try:
         with codecs.open(filename, 'r', 'utf-8') as f:
-            if hasattr(parser, 'read_file'):
-                parser.read_file(f)
-            else:
-                parser.readfp(f)
+            parser.read_file(f)
     except TypeError:
         pass
-    except EnvironmentError:
+    except OSError:
         pass
     except (DuplicateSectionError, ParsingError) as exc:
         ini_logger.warning('Could not parse %s' % filename)
@@ -164,7 +159,7 @@ class IniSectionListAttribute(IniSectionAttribute):
         return values
 
 
-class IniSectionObject(with_metaclass(UniventionMetaClass, object)):
+class IniSectionObject(metaclass=UniventionMetaClass):
     _main_attr_name = 'name'
 
     def __init__(self, **kwargs):
@@ -224,7 +219,7 @@ class TypedIniSectionObjectMetaClass(UniventionMetaClass):
         return new_cls
 
 
-class TypedIniSectionObject(with_metaclass(TypedIniSectionObjectMetaClass, IniSectionObject)):
+class TypedIniSectionObject(IniSectionObject, metaclass=TypedIniSectionObjectMetaClass):
     _type_attr = 'type'
 
     @classmethod
