@@ -38,8 +38,6 @@
 import os
 import os.path
 
-from six import string_types
-
 from univention.appcenter.ini_parser import (
     IniSectionAttribute, IniSectionBooleanAttribute, IniSectionListAttribute, TypedIniSectionObject,
 )
@@ -90,7 +88,7 @@ class Setting(TypedIniSectionObject):
             value = ucr_get(self.name)
             if value is not None:
                 return self.sanitize_value(app, value)
-        if isinstance(self.initial_value, string_types):
+        if isinstance(self.initial_value, str):
             return ucr_run_filter(self.initial_value)
         return self.initial_value
 
@@ -205,7 +203,7 @@ class FileSetting(Setting):
         try:
             with open(filename) as fd:
                 return fd.read()
-        except EnvironmentError:
+        except OSError:
             return None
 
     def _touch_file(self, filename):
@@ -224,7 +222,7 @@ class FileSetting(Setting):
                 settings_logger.debug('Deleting %s' % filename)
                 if os.path.exists(filename):
                     os.unlink(filename)
-        except EnvironmentError as exc:
+        except OSError as exc:
             settings_logger.error('Could not set content: %s' % exc)
 
     def get_value(self, app, phase='Settings'):
