@@ -37,8 +37,6 @@
 
 from copy import deepcopy
 
-import six
-
 from univention.config_registry import ConfigRegistry
 from univention.config_registry.frontend import ucr_update
 from univention.config_registry.handler import run_filter
@@ -56,10 +54,6 @@ def ucr_get(key, default=None):
     return _UCR.get(key, default)
 
 
-def ucr_get_int(key, default=None):
-    return _UCR.get_int(key, default)
-
-
 def ucr_save(values):
     changed_values = {}
     _UCR.load()
@@ -88,7 +82,7 @@ def ucr_keys():
 
 
 def ucr_evaluated_as_true(value):
-    if isinstance(value, six.string_types):
+    if isinstance(value, str):
         value = value.lower()
     return _UCR.is_true(value=value)
 
@@ -101,10 +95,7 @@ def ucr_run_filter(string, additional=None):
         ucr = deepcopy(ucr)
         for k, v in additional.items():
             ucr[k] = str(v)
-    value = run_filter(string, ucr)
-    if six.PY2:
-        return value
-    return value.decode('UTF-8')
+    return run_filter(string, ucr).decode('UTF-8')
 
 
 def ucr_instance():
