@@ -172,7 +172,7 @@ class Instance(umcm.Base, ProgressMixin):
 
         try:
             log_to_logfile()
-        except IOError:
+        except OSError:
             pass
 
         # connect univention.appcenter.log to the progress-method
@@ -324,9 +324,6 @@ class Instance(umcm.Base, ProgressMixin):
         return ret
 
     def _run_local(self, app, action, settings, auto_installed, progress):
-        for setting in app.get_settings():
-            if isinstance(setting, FileSetting) and not isinstance(setting, PasswordFileSetting) and settings.get(app.id, {}).get(setting.name):
-                settings[app.id][setting.name] = b64decode(settings[app.id][setting.name]).decode('utf-8')
         kwargs = {
             'noninteractive': True,
             'auto_installed': auto_installed,
@@ -386,7 +383,7 @@ class Instance(umcm.Base, ProgressMixin):
             try:
                 with open(query_cache_file) as fd:
                     return json.load(fd)
-            except (EnvironmentError, ValueError) as exc:
+            except (OSError, ValueError) as exc:
                 MODULE.error('Error returning cached query: %s' % exc)
                 return []
         self.update_applications()
@@ -434,7 +431,7 @@ class Instance(umcm.Base, ProgressMixin):
             cache_file = cache.get_cache_file('.suggestions.json')
             with open(cache_file) as fd:
                 json = load(fd)
-        except (EnvironmentError, ValueError):
+        except (OSError, ValueError):
             raise umcm.UMC_Error(_('Could not load suggestions.'))
         else:
             try:
@@ -602,7 +599,8 @@ class Instance(umcm.Base, ProgressMixin):
         sections = set()
         cache = apt.Cache()
         for package in cache:
-            sections.add(package.section)
+            if package.candidate:
+                sections.add(package.candidate.section)
 
         return sorted(sections)
 
@@ -612,7 +610,7 @@ class Instance(umcm.Base, ProgressMixin):
         """Query to fill the grid. Structure is fixed here."""
         result = []
         for package in self.package_manager.packages(reopen=True):
-            if section in ('all', package.section):
+            if section in ('all', package.candidate and package.candidate.section):
                 toshow = False
                 if pattern.pattern == '^.*$':
                     toshow = True
@@ -756,7 +754,7 @@ class Instance(umcm.Base, ProgressMixin):
         if full:
             # Some fields differ depending on whether the package is installed or not:
             if package.is_installed:
-                result['section'] = installed.section
+                result['section'] = candidate.section
                 result['priority'] = installed.priority or ''
                 result['summary'] = installed.summary   # take the current one
                 result['description'] = installed.description
