@@ -34,15 +34,15 @@
 # /usr/share/common-licenses/AGPL-3; if not, see
 # <https://www.gnu.org/licenses/>.
 
+# import psutil # our psutil is outdated. re-enable when methods are supported
+import http.client
 import os.path
 import ssl
+import urllib.request
 from contextlib import contextmanager
 from hashlib import md5
 from urllib.parse import ParseResult, urlparse
 
-# import psutil # our psutil is outdated. re-enable when methods are supported
-from six.moves import http_client, urllib_request
-
 import univention.management.console as umc
 from univention.admin.handlers.computers import (
     domaincontroller_backup, domaincontroller_master, domaincontroller_slave, memberserver,
@@ -57,28 +57,6 @@ from .constants import COMP_PARAMS, COMPONENT_BASE, DEFAULT_ICON, PUT_PROCESSING
 _ = umc.Translation('univention-management-console-module-appcenter').translate
 
 
-def rename_app(old_id, new_id, component_manager, package_manager):
-    from univention.management.console.modules.appcenter.app_center import Application
-    app = Application.find(old_id)
-    if not app:
-        app = Application.find(new_id)
-    if not app:
-        MODULE.error('Found neither OLD_ID nor NEW_ID.\n')
-        raise ValueError([old_id, new_id])
-
-    if not app.is_installed(package_manager, strict=False):
-        MODULE.process('%s is not installed. Fine, nothing to do.\n' % app.name)
-        return
-
-    app.set_id(old_id)
-    app.unregister_all_and_register(None, component_manager, package_manager)
-    app.tell_ldap(component_manager.ucr, package_manager, inform_about_error=False)
-
-    app.set_id(new_id)
-    app.register(component_manager, package_manager)
-    app.tell_ldap(component_manager.ucr, package_manager, inform_about_error=False)
-
-
 def get_hosts(module, lo, ucr=None):
     _hosts = module.lookup(None, lo, None)
     hosts = []
@@ -149,7 +127,7 @@ def create_url(server: str, prefix: str, username: str, password: str, port: str
     return ParseResult(scheme=scheme, netloc=netloc, path=path, params='', query='', fragment='').geturl()
 
 
-class HTTPSConnection(http_client.HTTPSConnection):
+class HTTPSConnection(http.client.HTTPSConnection):
     """Verified HTTP Connection, Bug #30620"""
 
     def __init__(self, *args, **kwargs):
@@ -161,7 +139,7 @@ class HTTPSConnection(http_client.HTTPSConnection):
         super(HTTPSConnection, self).__init__(*args, context=ssl_context, **kwargs)
 
 
-class HTTPSHandler(urllib_request.HTTPSHandler):
+class HTTPSHandler(urllib.request.HTTPSHandler):
 
     def https_open(self, req):
         return self.do_open(HTTPSConnection, req)
@@ -176,16 +154,16 @@ def install_opener(ucr):
     handler = []
     proxy_http = ucr.get('proxy/http')
     if proxy_http:
-        handler.append(urllib_request.ProxyHandler({'http': proxy_http, 'https': proxy_http}))
+        handler.append(urllib.request.ProxyHandler({'http': proxy_http, 'https': proxy_http}))
     handler.append(HTTPSHandler())
-    opener = urllib_request.build_opener(*handler)
-    urllib_request.install_opener(opener)
+    opener = urllib.request.build_opener(*handler)
+    urllib.request.install_opener(opener)
 
 
 def urlopen(request):
     # use this in __init__ and app_center
     # to have the proxy handler installed globally
-    return urllib_request.urlopen(request, timeout=60)
+    return urllib.request.urlopen(request, timeout=60)  # noqa: S310
 
 
 def get_current_ram_available():
@@ -364,8 +342,6 @@ class ComponentManager(object):
         }
         if not self.is_registered(app_data['name']):
             # do not overwrite version when registering apps
-            # (like in univention-register-apps which is called
-            # in a join script)
             # it may have been changed intentionally, see EndOfLife
             app_data['version'] = 'current'
         self.put(app_data, super_ucr)
